@@ -303,7 +303,9 @@ def top_k_top_p_filtering(logits, top_k=0, top_p=0.0, filter_value=-float('Inf')
     return logits
 
 def t5_random_sample(model, tokenizer, text, input_max_length, out_max_length,
-                     top_k, top_p, repetition_penalty, temperature, device):
+                     top_k, top_p, repetition_penalty, temperature, device, seed=123):
+    torch.manual_seed(seed)
+
     token_ids = tokenizer.encode_plus(text, max_length=input_max_length)["input_ids"]
     token_ids = torch.tensor(token_ids, device=device, dtype=torch.long).view(1, -1)
     output_ids = []
@@ -331,9 +333,10 @@ def t5_random_sample(model, tokenizer, text, input_max_length, out_max_length,
     return tokenizer.decode(output_ids)
 
 def gpt_random_sample(model, tokenizer, text, input_max_length, out_max_length,
-                      top_k, top_p, repetition_penalty, temperature, device):
+                      top_k, top_p, repetition_penalty, temperature, device, seed=123):
+    torch.manual_seed(seed)
     tokenizer_out = tokenizer.encode_plus(text, max_length=input_max_length)
-    token_ids = tokenizer_out["input_ids"]
+    token_ids = tokenizer_out["input_ids"][:-1]
 
     lp = [RepetitionPenaltyLogitsProcessor(penalty=repetition_penalty),
           TemperatureLogitsProcessor(temperature=temperature),
@@ -360,6 +363,38 @@ def gpt_random_sample(model, tokenizer, text, input_max_length, out_max_length,
 
     return tokenizer.decode(output_ids)
 
+def bert_random_sample(model, tokenizer, text, input_max_length, out_max_length,
+                       top_k, top_p, repetition_penalty, temperature, device, seed=123):
+    torch.manual_seed(seed)
+    tokenizer_out = tokenizer.encode_plus(text, max_length=input_max_length)
+    token_ids = tokenizer_out["input_ids"]
+    token_type_ids = tokenizer_out["token_type_ids"]
+    token_ids = torch.tensor(token_ids, device=device, dtype=torch.long).view(1, -1)
+    token_type_ids = torch.tensor(token_type_ids, device=device, dtype=torch.long).view(1, -1)
+
+    output_ids = []
+    lp = [RepetitionPenaltyLogitsProcessor(penalty=repetition_penalty),
+          TemperatureLogitsProcessor(temperature=temperature),
+          TopKLogitsProcessor(top_k=top_k),
+          TopPLogitsProcessor(top_p=top_p),
+          ]
+    list_processor = ListProcessor(lp)
+    with torch.no_grad():
+        for step in range(out_max_length):
+            scores = model(**{"input_ids":token_ids, "token_type_ids":token_type_ids})["logits"]
+            logit_score = torch.log_softmax(scores[:, -1], dim=-1)
+            logit_score[:, tokenizer.token_unk_id] = -float('Inf')
+            filtered_logits = list_processor(token_ids, logit_score)
+
+            filterd_logits_prob = F.softmax(filtered_logits, dim=-1)
+            next_token = torch.multinomial(filterd_logits_prob, num_samples=1)
+            if tokenizer.token_end_id == next_token.item():
+                break
+            output_ids.append(next_token.item())
+            token_ids = torch.cat((token_ids, next_token.long()), dim=1)
+            token_type_ids = torch.cat((token_type_ids, torch.tensor([[1]], device=device, dtype=torch.long)), dim=1)
+    return tokenizer.decode(output_ids)
+
 def bert_beamsearch(model, tokenizer, text, input_max_length, out_max_length, beam_size):
     tokenizer_out = tokenizer.encode_plus(text, max_length=input_max_length)
     vocab = tokenizer.vocab
