@@ -12,6 +12,7 @@ from bert_seq2seq.task.sequence_labeling.bert_sequence_labeling import BertNERGP
 # from bert_seq2seq.gpt2_generate_model import GPT2
 # from bert_seq2seq.basic_bert import BasicBert
 from bert_seq2seq.task.seq2seq.gpt2_seq2seq_model import GPT2
+from bert_seq2seq.task.seq2seq.t5_seq2seq_model import T5Model
 
 ALL_TASK = {
     "bert_seq2seq": BertSeq2SeqModel,
@@ -30,13 +31,17 @@ ALL_TASK = {
     "roberta_embedding": BertEmbedding,
     "roberta-large_embedding": BertEmbedding,
     "gpt2_seq2seq": GPT2,
+    "t5_seq2seq": T5Model,
 }
 
-def load_model(vocab, model_name="roberta", task_name="seq2seq", target_size=0, ner_inner_dim=-1):
+def load_model(vocab, model_name="roberta", task_name="seq2seq", target_size=0, ner_inner_dim=-1, size="base"):
     task_model = ALL_TASK.get(f"{model_name}_{task_name}", None)
     if task_model is None :
         print("no this task")
         os._exit(0)
 
-    return task_model(vocab, model_name=model_name, target_size=target_size, ent_type_size=target_size, inner_dim=ner_inner_dim)
+    return task_model(vocab, model_name=model_name, size=size,
+                      target_size=target_size,
+                      ent_type_size=target_size,
+                      inner_dim=ner_inner_dim)
 
